pub enum Route<'lf> {
Stack(&'lf str, &'lf [Route<'lf>]),
Tail(Method, &'lf str, Function),
}Expand description
A quick way of nesting routes inside of eachother stacks can contain either yet another stack, or a tail, which will act as an API-endpoint. This enum is used for the server config when initializing the server.
Examples
/*- Initiaize routes -*/
let routes = Route::Stack("", &[
Route::Stack("nest1", &[
Route::Tail(Method::POST, "value", Function::S(|_| {})),
Route::Stack("nest2", &[
Route::Tail(Method::GET, "value1", Function::S(|_| {})),
Route::Tail(Method::GET, "value2", Function::S(|_| {})),
]),
]),
]);Variants