pub fn with_file(path: &str) -> Option<Respond>
Will return a Respond struct containing information to send a file, like an image, text, or json file
respond(&mut stream, 200u16, with_file("/path/to/file.png"))